Structs
- Moving
Median - Fixed size queue, which calculate moving median when you add new value. sampling size must be odd number because this can be used for all PartialOrd(and Clone) types computational complexity: O(n) for calculating median, O(nlog(n)) only for first calculation because it simply sorts and finds median.